> [!IMPORTANT]
> We're excited you're checking out Hegel! Hegel is in beta, and we'd love for you to try it and [report any feedback](https://github.com/hegeldev/hegel-core/issues/new).
>
> As part of our beta, we may make breaking changes if it makes Hegel a better property-based testing protocol. If that instability bothers you, please check back in a few months for a stable release!
>
> See https://hegel.dev/compatibility for more details.

# Hegel

* [Website](https://hegel.dev)
* [hegel-rust](https://github.com/hegeldev/hegel-rust)

The Hegel protocol and server, built on [Hypothesis](https://github.com/hypothesisworks/hypothesis).  `hegel-core` provides the core functionality of a property-based testing library, including data generation and shrinking.
